@@ -4,11 +4,14 @@ use strict;
 use warnings;
 use Carp ();
 
-our $VERSION = '0.97_04';
+our $VERSION = '0.97_05';
 
 sub new {
 	my $class = shift;
-	my $self  = bless { @_ }, $class;
+	my $self  = bless {
+		@_,
+		installed => 0,
+	}, $class;
 
 	# Validate the advice and pointcut combination
 	my $error = $self->_validate;
@@ -32,6 +35,10 @@ sub lexical {
 	$_[0]->{lexical};
 }
 
+sub installed {
+	$_[0]->{installed};
+}
+
 sub DESTROY {
 	$_[0]->{hook}->() if $_[0]->{hook};
 }
