@@ -9,11 +9,11 @@ use Carp::Heavy                  ();
 use Carp                         ();
 use Sub::Uplevel                 ();
 use Aspect::Hook                 ();
-use Aspect::Advice               ();
+use Aspect::Advice::After        ();
 use Aspect::Point::AfterThrowing ();
 
-our $VERSION = '0.97_04';
-our @ISA     = 'Aspect::Advice';
+our $VERSION = '0.97_05';
+our @ISA     = 'Aspect::Advice::After';
 
 # NOTE: To simplify debugging of the generated code, all injected string
 # fragments will be defined in $UPPERCASE, and all lexical variables to be
@@ -28,7 +28,7 @@ sub _install {
 	# runtime checks instead of the original.
 	# Because $MATCH_RUN is used in boolean conditionals, if there
 	# is nothing to do the compiler will optimise away the code entirely.
-	my $curried   = $pointcut->match_curry;
+	my $curried   = $pointcut->curry_runtime;
 	my $compiled  = $curried ? $curried->compiled_runtime : undef;
 	my $MATCH_RUN = $compiled ? '$compiled->()' : 1;
 
@@ -81,7 +81,7 @@ sub _install {
 				local \$_ = bless {
 					sub_name     => \$name,
 					wantarray    => \$wantarray,
-					params       => \\\@_,
+					args         => \\\@_,
 					return_value => \$return,
 					exception    => \$\@,
 					pointcut     => \$pointcut,
@@ -91,10 +91,10 @@ sub _install {
 				die \$_->{exception} unless $MATCH_RUN;
 
 				# Execute the advice code
-				() = &\$code(\$_);
+				&\$code(\$_);
 
 				# Throw the same (or modified) exception
-				my \$exception = \$_->exception;
+				my \$exception = \$_->{exception};
 				die \$exception if \$exception;
 
 				# Get the (potentially) modified return value
@@ -112,7 +112,7 @@ sub _install {
 				local \$_ = bless {
 					sub_name     => \$name,
 					wantarray    => \$wantarray,
-					params       => \\\@_,
+					args         => \\\@_,
 					return_value => \$return,
 					exception    => \$\@,
 					pointcut     => \$pointcut,
@@ -122,10 +122,10 @@ sub _install {
 				die \$_->{exception} unless $MATCH_RUN;
 
 				# Execute the advice code
-				my \$dummy = &\$code(\$_);
+				&\$code(\$_);
 
 				# Throw the same (or modified) exception
-				my \$exception = \$_->exception;
+				my \$exception = \$_->{exception};
 				die \$exception if \$exception;
 
 				# Return the potentially-modified value
@@ -142,7 +142,7 @@ sub _install {
 				local \$_ = bless {
 					sub_name     => \$name,
 					wantarray    => \$wantarray,
-					params       => \\\@_,
+					args         => \\\@_,
 					return_value => undef,
 					exception    => \$\@,
 					pointcut     => \$pointcut,
@@ -155,13 +155,14 @@ sub _install {
 				&\$code(\$_);
 
 				# Throw the same (or modified) exception
-				my \$exception = \$_->exception;
+				my \$exception = \$_->{exception};
 				die \$exception if \$exception;
 
 				return;
 			}
 		};
 END_PERL
+		$self->{installed}++;
 	}
 
 	# If this will run lexical we don't need a descoping hook
@@ -174,6 +175,19 @@ END_PERL
 	return sub { $out_of_scope = 1 };
 }
 
+# Check for pointcut usage not supported by the advice type
+sub _validate {
+	my $self     = shift;
+	my $pointcut = $self->pointcut;
+
+	# Pointcuts using "throwing" are irrelevant in before advice
+	if ( $pointcut->match_contains('Aspect::Pointcut::Returning') ) {
+		return 'The pointcut returning is illegal when used by after_throwing advice';
+	}
+
+	$self->SUPER::_validate(@_);
+}
+
 1;
 
 __END__
@@ -195,7 +209,7 @@ exception
   
       # Suppress stringwise "bar" errors from foo() and return true instead
       if (
-          $_->short_sub_name eq 'foo'
+          $_->short_name eq 'foo'
           and
           ref $_->exception
           and
