@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use Aspect::Library ();
 
-our $VERSION = '0.97_04';
+our $VERSION = '0.97_05';
 our @ISA     = 'Aspect::Library';
 
 sub new {
@@ -13,7 +13,7 @@ sub new {
 
 	# Generate the appropriate advice
 	$self->{advice} = [
-		$self->get_advice( $self->params )
+		$self->get_advice( $self->args )
 	];
 
 	# Warn if the aspect is supposed to be permanent,
@@ -31,8 +31,8 @@ sub new {
 	return $self;
 }
 
-sub params {
-	@{$_[0]->{params}};
+sub args {
+	@{$_[0]->{args}};
 }
 
 sub lexical {
@@ -44,7 +44,16 @@ sub get_advice {
 	die("Method 'get_advice' is not implemented by class '$class'");
 }
 
-1;
+
+
+
+
+######################################################################
+# Back Compatibility
+
+BEGIN {
+	*params = *args;
+}
 
 
 
@@ -65,6 +74,8 @@ use Class::XSAccessor 1.08 {
 END_PERL
 }
 
+1;
+
 __END__
 
 =pod
