@@ -1,10 +1,21 @@
 package Aspect::Point::Around;
+=pod
+
+=head1 NAME
+
+Aspect::Point - The Join Point context for "around" advice code
+
+=head1 SYNOPSIS
+
+=head1 METHODS
+
+=cut
 
 use strict;
 use warnings;
 use Aspect::Point ();
 
-our $VERSION = '0.97_04';
+our $VERSION = '0.97_05';
 our @ISA     = 'Aspect::Point';
 
 use constant type => 'around';
@@ -13,13 +24,6 @@ sub original {
 	$_[0]->{original};
 }
 
-sub exception {
-	my $self = shift;
-	return $self->{exception} unless @_;
-	$self->{proceed}   = 0;
-	$self->{exception} = shift;
-}
-
 sub proceed {
 	my $self = shift;
 
@@ -27,7 +31,7 @@ sub proceed {
 		Sub::Uplevel::uplevel(
 			2,
 			$self->{original},
-			@{$self->{params}},
+			@{$self->{args}},
 		)
 	) if $self->{wantarray};
 
@@ -35,14 +39,14 @@ sub proceed {
 		scalar Sub::Uplevel::uplevel(
 			2,
 			$self->{original},
-			@{$self->{params}},
+			@{$self->{args}},
 		)
 	) if defined $self->{wantarray};
 
 	return Sub::Uplevel::uplevel(
 		2,
 		$self->{original},
-		@{$self->{params}},
+		@{$self->{args}},
 	);
 }
 
@@ -70,3 +74,24 @@ END_PERL
 }
 
 1;
+
+=pod
+
+=head1 AUTHORS
+
+Adam Kennedy E<lt>adamk@cpan.orgE<gt>
+
+Marcel GrE<uuml>nauer E<lt>marcel@cpan.orgE<gt>
+
+Ran Eilam E<lt>eilara@cpan.orgE<gt>
+
+=head1 COPYRIGHT
+
+Copyright 2001 by Marcel GrE<uuml>nauer
+
+Some parts copyright 2009 - 2011 Adam Kennedy.
+
+This library is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself.
+
+=cut
